pub struct SampleWrite {Show 13 fields
pub sampled_at: DateTime<Utc>,
pub cpu_percent: Option<f32>,
pub vcpu_time_ns: Option<u64>,
pub memory_bytes: Option<u64>,
pub memory_available_bytes: Option<u64>,
pub memory_host_resident_bytes: Option<u64>,
pub disk_read_bytes: u64,
pub disk_write_bytes: u64,
pub net_rx_bytes: u64,
pub net_tx_bytes: u64,
pub upper_used_bytes: Option<u64>,
pub upper_free_bytes: Option<u64>,
pub upper_host_allocated_bytes: Option<u64>,
}Expand description
Sample bytes to write into a slot.
Fields
sampled_at: DateTime<Utc>Wall-clock time the sample was captured.
cpu_percent: Option<f32>Guest vCPU usage as a percentage when sourced by the VMM.
vcpu_time_ns: Option<u64>Cumulative guest vCPU execution time across all vCPUs when sourced by the VMM.
memory_bytes: Option<u64>Guest-used memory in bytes when sourced by the guest.
memory_available_bytes: Option<u64>Guest-available memory in bytes when reported by the guest.
memory_host_resident_bytes: Option<u64>Host-resident guest memory in bytes for capacity diagnostics.
disk_read_bytes: u64Cumulative disk bytes read.
disk_write_bytes: u64Cumulative disk bytes written.
net_rx_bytes: u64Cumulative network bytes received.
net_tx_bytes: u64Cumulative network bytes transmitted.
upper_used_bytes: Option<u64>Guest-visible OCI upper filesystem used bytes when available.
upper_free_bytes: Option<u64>Guest-visible OCI upper filesystem free bytes when available.
upper_host_allocated_bytes: Option<u64>Host-allocated bytes for the writable upper image when available.